@@ -8,7 +8,7 @@ import gamelib.Utils as Utils
 import time
 import sys
 
-board_to_load = 'hac-maps/test-board.json'
+board_to_load = "hac-maps/test-board.json"
 
 if len(sys.argv) > 1:
     board_to_load = sys.argv[1]
@@ -25,6 +25,7 @@ b = g.load_board(board_to_load, 1)
 print(b)
 
 g.player = Player(model=Sprites.FLYING_SAUCER)
+g.player.inventory.max_size = 99999
 g.change_level(1)
 
 
@@ -32,15 +33,15 @@ idx = 0
 key = None
 
 while idx < max_iter or max_iter == 0:
-    if key == 'w':
+    if key == "w":
         g.move_player(Constants.UP, 1)
-    elif key == 's':
+    elif key == "s":
         g.move_player(Constants.DOWN, 1)
-    elif key == 'a':
+    elif key == "a":
         g.move_player(Constants.LEFT, 1)
-    elif key == 'd':
+    elif key == "d":
         g.move_player(Constants.RIGHT, 1)
-    elif key == 'q':
+    elif key == "q":
         break
     g.clear_screen()
     g.actuate_npcs(1)
